# Generated by Django 2.2.13 on 2020-06-18 16:21

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("standingsrequests", "0002_contactlabel_labelid_bigintegerfield"),
    ]

    operations = [
        migrations.RenameField(
            model_name="abstractstandingsrequest",
            old_name="actionBy",
            new_name="action_by",
        ),
        migrations.RenameField(
            model_name="abstractstandingsrequest",
            old_name="actionDate",
            new_name="action_date",
        ),
        migrations.RenameField(
            model_name="abstractstandingsrequest",
            old_name="contactID",
            new_name="contact_id",
        ),
        migrations.RenameField(
            model_name="abstractstandingsrequest",
            old_name="contactType",
            new_name="contact_type_id",
        ),
        migrations.RenameField(
            model_name="abstractstandingsrequest",
            old_name="effectiveDate",
            new_name="effective_date",
        ),
        migrations.RenameField(
            model_name="abstractstandingsrequest",
            old_name="effective",
            new_name="is_effective",
        ),
        migrations.RenameField(
            model_name="abstractstandingsrequest",
            old_name="requestDate",
            new_name="request_date",
        ),
        migrations.RenameField(
            model_name="alliancestanding", old_name="contactID", new_name="contact_id",
        ),
        migrations.RenameField(
            model_name="alliancestanding", old_name="set", new_name="contact_set",
        ),
        migrations.RenameField(
            model_name="contactlabel", old_name="set", new_name="contact_set",
        ),
        migrations.RenameField(
            model_name="contactlabel", old_name="labelID", new_name="label_id",
        ),
        migrations.RenameField(
            model_name="corpstanding", old_name="contactID", new_name="contact_id",
        ),
        migrations.RenameField(
            model_name="corpstanding", old_name="set", new_name="contact_set",
        ),
        migrations.RenameField(
            model_name="evenamecache", old_name="entityID", new_name="entity_id",
        ),
        migrations.RenameField(
            model_name="pilotstanding", old_name="contactID", new_name="contact_id",
        ),
        migrations.RenameField(
            model_name="pilotstanding", old_name="set", new_name="contact_set",
        ),
        migrations.RenameField(
            model_name="pilotstanding", old_name="inWatchlist", new_name="is_watched",
        ),
    ]
