<span ng-switch on="standingIcon">
    <i ng-switch-when="-10" class="fas fa-minus-square fa-fw grayiconecolor" style="color:#930404;" title="{{ standing }}"></i>
    <i ng-switch-when="-5" class="fas fa-minus-square fa-fw grayiconecolor" style="color:#c34704;" title="{{ standing }}"></i>
    <i ng-switch-when="0" class="fas fa-bars fa-fw grayiconecolor" style="color:#878787;" title="{{ standing }}"></i>
    <i ng-switch-when="5" class="fas fa-plus-square fa-fw grayiconecolor" style="color:#2a64c3;" title="{{ standing }}"></i>
    <i ng-switch-when="10" class="fas fa-plus-square fa-fw grayiconecolor" style="color:#042177;" title="{{ standing }}"></i>
    <i ng-switch-default class="fas fa-question fa-fw grayiconecolor" style="color:#F2A600;" title="Unknown"></i>
</span>